# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/event_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/event_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bgrid/v1/event_service.proto\x12\x07grid.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x13grid/v1/event.proto\"\xd5\x01\n\x0b\x45ventFilter\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12:\n\rresource_type\x18\x02 \x01(\x0e\x32\x15.grid.v1.ResourceTypeR\x0cresourceType\x12\x31\n\nevent_type\x18\x03 \x01(\x0e\x32\x12.grid.v1.EventTypeR\teventType\x12\x1f\n\x0bresource_id\x18\x04 \x01(\tR\nresourceId\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\"\xd9\x01\n\x10GetEventsRequest\x12,\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x14.grid.v1.EventFilterR\x06\x66ilter\x12.\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12*\n\x02to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02to\x12%\n\x0e\x63ontinue_token\x18\x04 \x01(\tR\rcontinueToken\x12\x14\n\x05limit\x18\x05 \x01(\x03R\x05limit\"b\n\x11GetEventsResponse\x12&\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x0e.grid.v1.EventR\x06\x65vents\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\"B\n\x12WatchEventsRequest\x12,\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x14.grid.v1.EventFilterR\x06\x66ilter\"=\n\x13WatchEventsResponse\x12&\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x0e.grid.v1.EventR\x06\x65vents2\x9e\x01\n\x0c\x45ventService\x12\x42\n\tGetEvents\x12\x19.grid.v1.GetEventsRequest\x1a\x1a.grid.v1.GetEventsResponse\x12J\n\x0bWatchEvents\x12\x1b.grid.v1.WatchEventsRequest\x1a\x1c.grid.v1.WatchEventsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,grid_dot_v1_dot_event__pb2.DESCRIPTOR,])




_EVENTFILTER = _descriptor.Descriptor(
  name='EventFilter',
  full_name='grid.v1.EventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.EventFilter.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='grid.v1.EventFilter.resource_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='grid.v1.EventFilter.event_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='grid.v1.EventFilter.resource_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.EventFilter.cluster_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=335,
)


_GETEVENTSREQUEST = _descriptor.Descriptor(
  name='GetEventsRequest',
  full_name='grid.v1.GetEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='grid.v1.GetEventsRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='filter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from', full_name='grid.v1.GetEventsRequest.from', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='from', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='grid.v1.GetEventsRequest.to', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='to', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.GetEventsRequest.continue_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.GetEventsRequest.limit', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=555,
)


_GETEVENTSRESPONSE = _descriptor.Descriptor(
  name='GetEventsResponse',
  full_name='grid.v1.GetEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='grid.v1.GetEventsResponse.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='events', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.GetEventsResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=557,
  serialized_end=655,
)


_WATCHEVENTSREQUEST = _descriptor.Descriptor(
  name='WatchEventsRequest',
  full_name='grid.v1.WatchEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='grid.v1.WatchEventsRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='filter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=657,
  serialized_end=723,
)


_WATCHEVENTSRESPONSE = _descriptor.Descriptor(
  name='WatchEventsResponse',
  full_name='grid.v1.WatchEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='grid.v1.WatchEventsResponse.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='events', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=725,
  serialized_end=786,
)

_EVENTFILTER.fields_by_name['resource_type'].enum_type = grid_dot_v1_dot_event__pb2._RESOURCETYPE
_EVENTFILTER.fields_by_name['event_type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_GETEVENTSREQUEST.fields_by_name['filter'].message_type = _EVENTFILTER
_GETEVENTSREQUEST.fields_by_name['from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETEVENTSREQUEST.fields_by_name['to'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETEVENTSRESPONSE.fields_by_name['events'].message_type = grid_dot_v1_dot_event__pb2._EVENT
_WATCHEVENTSREQUEST.fields_by_name['filter'].message_type = _EVENTFILTER
_WATCHEVENTSRESPONSE.fields_by_name['events'].message_type = grid_dot_v1_dot_event__pb2._EVENT
DESCRIPTOR.message_types_by_name['EventFilter'] = _EVENTFILTER
DESCRIPTOR.message_types_by_name['GetEventsRequest'] = _GETEVENTSREQUEST
DESCRIPTOR.message_types_by_name['GetEventsResponse'] = _GETEVENTSRESPONSE
DESCRIPTOR.message_types_by_name['WatchEventsRequest'] = _WATCHEVENTSREQUEST
DESCRIPTOR.message_types_by_name['WatchEventsResponse'] = _WATCHEVENTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventFilter = _reflection.GeneratedProtocolMessageType('EventFilter', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFILTER,
  '__module__' : 'grid.v1.event_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.EventFilter)
  })
_sym_db.RegisterMessage(EventFilter)

GetEventsRequest = _reflection.GeneratedProtocolMessageType('GetEventsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTSREQUEST,
  '__module__' : 'grid.v1.event_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetEventsRequest)
  })
_sym_db.RegisterMessage(GetEventsRequest)

GetEventsResponse = _reflection.GeneratedProtocolMessageType('GetEventsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTSRESPONSE,
  '__module__' : 'grid.v1.event_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetEventsResponse)
  })
_sym_db.RegisterMessage(GetEventsResponse)

WatchEventsRequest = _reflection.GeneratedProtocolMessageType('WatchEventsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHEVENTSREQUEST,
  '__module__' : 'grid.v1.event_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchEventsRequest)
  })
_sym_db.RegisterMessage(WatchEventsRequest)

WatchEventsResponse = _reflection.GeneratedProtocolMessageType('WatchEventsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHEVENTSRESPONSE,
  '__module__' : 'grid.v1.event_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchEventsResponse)
  })
_sym_db.RegisterMessage(WatchEventsResponse)


DESCRIPTOR._options = None

_EVENTSERVICE = _descriptor.ServiceDescriptor(
  name='EventService',
  full_name='grid.v1.EventService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=789,
  serialized_end=947,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetEvents',
    full_name='grid.v1.EventService.GetEvents',
    index=0,
    containing_service=None,
    input_type=_GETEVENTSREQUEST,
    output_type=_GETEVENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchEvents',
    full_name='grid.v1.EventService.WatchEvents',
    index=1,
    containing_service=None,
    input_type=_WATCHEVENTSREQUEST,
    output_type=_WATCHEVENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EVENTSERVICE)

DESCRIPTOR.services_by_name['EventService'] = _EVENTSERVICE

# @@protoc_insertion_point(module_scope)
