# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/run.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import experiment_pb2 as grid_dot_v1_dot_experiment__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/run.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11grid/v1/run.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x18grid/v1/experiment.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\x86\x01\n\x03Run\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12$\n\x04spec\x18\x02 \x01(\x0b\x32\x10.grid.v1.RunSpecR\x04spec\x12*\n\x06status\x18\x03 \x01(\x0b\x32\x12.grid.v1.RunStatusR\x06status\"\xd9\x01\n\x07RunSpec\x12/\n\x08template\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\x08template\x12:\n\tgenerator\x18\x02 \x01(\x0b\x32\x1c.grid.v1.ExperimentGeneratorR\tgenerator\x12\x36\n\rdesired_state\x18\x03 \x01(\x0e\x32\x11.grid.v1.RunStateR\x0c\x64\x65siredState\x12)\n\x10pause_automation\x18\x04 \x01(\x08R\x0fpauseAutomation\"\xcc\x01\n\x13\x45xperimentGenerator\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x36\n\x0bgrid_search\x18\x02 \x01(\x0b\x32\x13.grid.v1.GridSearchH\x00R\ngridSearch\x12<\n\rrandom_search\x18\x03 \x01(\x0b\x32\x15.grid.v1.RandomSearchH\x00R\x0crandomSearchB\x0b\n\tgenerator\"\xcd\x01\n\x05Param\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x32\n\x08\x65xternal\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x32\n\x08\x64\x65screte\x18\x03 \x01(\x0b\x32\x14.grid.v1.DiscreteSetH\x00R\x08\x64\x65screte\x12\x38\n\x07uniform\x18\x04 \x01(\x0b\x32\x1c.grid.v1.UniformDistributionH\x00R\x07uniformB\x0e\n\x0c\x64istribution\"%\n\x0b\x44iscreteSet\x12\x16\n\x06values\x18\x01 \x03(\tR\x06values\"Z\n\x13UniformDistribution\x12\x10\n\x03min\x18\x01 \x01(\x02R\x03min\x12\x10\n\x03max\x18\x02 \x01(\x02R\x03max\x12\x1f\n\x0bnum_samples\x18\x03 \x01(\x05R\nnumSamples\"4\n\nGridSearch\x12&\n\x06params\x18\x01 \x03(\x0b\x32\x0e.grid.v1.ParamR\x06params\"U\n\x0cRandomSearch\x12&\n\x06params\x18\x01 \x03(\x0b\x32\x0e.grid.v1.ParamR\x06params\x12\x1d\n\nnum_trials\x18\x02 \x01(\x03R\tnumTrials\"\xda\x01\n\tRunStatus\x12\x41\n\x0b\x65xperiments\x18\x01 \x03(\x0b\x32\x1f.grid.v1.ExperimentSummaryEntryR\x0b\x65xperiments\x12\x43\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12\x45\n\x10\x66inish_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66inishTimestamp\"\x7f\n\x16\x45xperimentSummaryEntry\x12\x14\n\x05\x63ount\x18\x01 \x01(\x04R\x05\x63ount\x12\x30\n\x06status\x18\x02 \x01(\x0e\x32\x18.grid.v1.ExperimentStateR\x06status\x12\x1d\n\ncluster_id\x18\x03 \x01(\tR\tclusterId*\xc7\x01\n\x08RunState\x12\x19\n\x15RUN_STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11RUN_STATE_PENDING\x10\x01\x12\x14\n\x10RUN_STATE_QUEUED\x10\x02\x12\x15\n\x11RUN_STATE_RUNNING\x10\x03\x12\x17\n\x13RUN_STATE_COMPLETED\x10\x04\x12\x14\n\x10RUN_STATE_FAILED\x10\x05\x12\x16\n\x12RUN_STATE_CANCELED\x10\x06\x12\x15\n\x11RUN_STATE_DELETED\x10\x07\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_experiment__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_RUNSTATE = _descriptor.EnumDescriptor(
  name='RunState',
  full_name='grid.v1.RunState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_QUEUED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_RUNNING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_COMPLETED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_FAILED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_CANCELED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_DELETED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1535,
  serialized_end=1734,
)
_sym_db.RegisterEnumDescriptor(_RUNSTATE)

RunState = enum_type_wrapper.EnumTypeWrapper(_RUNSTATE)
RUN_STATE_UNSPECIFIED = 0
RUN_STATE_PENDING = 1
RUN_STATE_QUEUED = 2
RUN_STATE_RUNNING = 3
RUN_STATE_COMPLETED = 4
RUN_STATE_FAILED = 5
RUN_STATE_CANCELED = 6
RUN_STATE_DELETED = 7



_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='grid.v1.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='grid.v1.Run.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='grid.v1.Run.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='grid.v1.Run.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=275,
)


_RUNSPEC = _descriptor.Descriptor(
  name='RunSpec',
  full_name='grid.v1.RunSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='grid.v1.RunSpec.template', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='template', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generator', full_name='grid.v1.RunSpec.generator', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='generator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_state', full_name='grid.v1.RunSpec.desired_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='desiredState', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_automation', full_name='grid.v1.RunSpec.pause_automation', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pauseAutomation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=495,
)


_EXPERIMENTGENERATOR = _descriptor.Descriptor(
  name='ExperimentGenerator',
  full_name='grid.v1.ExperimentGenerator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external', full_name='grid.v1.ExperimentGenerator.external', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='external', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_search', full_name='grid.v1.ExperimentGenerator.grid_search', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='gridSearch', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_search', full_name='grid.v1.ExperimentGenerator.random_search', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='randomSearch', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='generator', full_name='grid.v1.ExperimentGenerator.generator',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=498,
  serialized_end=702,
)


_PARAM = _descriptor.Descriptor(
  name='Param',
  full_name='grid.v1.Param',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grid.v1.Param.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external', full_name='grid.v1.Param.external', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='external', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descrete', full_name='grid.v1.Param.descrete', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='descrete', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uniform', full_name='grid.v1.Param.uniform', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uniform', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='distribution', full_name='grid.v1.Param.distribution',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=705,
  serialized_end=910,
)


_DISCRETESET = _descriptor.Descriptor(
  name='DiscreteSet',
  full_name='grid.v1.DiscreteSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='grid.v1.DiscreteSet.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='values', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=949,
)


_UNIFORMDISTRIBUTION = _descriptor.Descriptor(
  name='UniformDistribution',
  full_name='grid.v1.UniformDistribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='grid.v1.UniformDistribution.min', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='min', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='grid.v1.UniformDistribution.max', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='max', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_samples', full_name='grid.v1.UniformDistribution.num_samples', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numSamples', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=951,
  serialized_end=1041,
)


_GRIDSEARCH = _descriptor.Descriptor(
  name='GridSearch',
  full_name='grid.v1.GridSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='grid.v1.GridSearch.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='params', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1043,
  serialized_end=1095,
)


_RANDOMSEARCH = _descriptor.Descriptor(
  name='RandomSearch',
  full_name='grid.v1.RandomSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='grid.v1.RandomSearch.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='params', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_trials', full_name='grid.v1.RandomSearch.num_trials', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numTrials', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1182,
)


_RUNSTATUS = _descriptor.Descriptor(
  name='RunStatus',
  full_name='grid.v1.RunStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiments', full_name='grid.v1.RunStatus.experiments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiments', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='grid.v1.RunStatus.start_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finish_timestamp', full_name='grid.v1.RunStatus.finish_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='finishTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1403,
)


_EXPERIMENTSUMMARYENTRY = _descriptor.Descriptor(
  name='ExperimentSummaryEntry',
  full_name='grid.v1.ExperimentSummaryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='grid.v1.ExperimentSummaryEntry.count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='count', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='grid.v1.ExperimentSummaryEntry.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.ExperimentSummaryEntry.cluster_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1405,
  serialized_end=1532,
)

_RUN.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_RUN.fields_by_name['spec'].message_type = _RUNSPEC
_RUN.fields_by_name['status'].message_type = _RUNSTATUS
_RUNSPEC.fields_by_name['template'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_RUNSPEC.fields_by_name['generator'].message_type = _EXPERIMENTGENERATOR
_RUNSPEC.fields_by_name['desired_state'].enum_type = _RUNSTATE
_EXPERIMENTGENERATOR.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EXPERIMENTGENERATOR.fields_by_name['grid_search'].message_type = _GRIDSEARCH
_EXPERIMENTGENERATOR.fields_by_name['random_search'].message_type = _RANDOMSEARCH
_EXPERIMENTGENERATOR.oneofs_by_name['generator'].fields.append(
  _EXPERIMENTGENERATOR.fields_by_name['external'])
_EXPERIMENTGENERATOR.fields_by_name['external'].containing_oneof = _EXPERIMENTGENERATOR.oneofs_by_name['generator']
_EXPERIMENTGENERATOR.oneofs_by_name['generator'].fields.append(
  _EXPERIMENTGENERATOR.fields_by_name['grid_search'])
_EXPERIMENTGENERATOR.fields_by_name['grid_search'].containing_oneof = _EXPERIMENTGENERATOR.oneofs_by_name['generator']
_EXPERIMENTGENERATOR.oneofs_by_name['generator'].fields.append(
  _EXPERIMENTGENERATOR.fields_by_name['random_search'])
_EXPERIMENTGENERATOR.fields_by_name['random_search'].containing_oneof = _EXPERIMENTGENERATOR.oneofs_by_name['generator']
_PARAM.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PARAM.fields_by_name['descrete'].message_type = _DISCRETESET
_PARAM.fields_by_name['uniform'].message_type = _UNIFORMDISTRIBUTION
_PARAM.oneofs_by_name['distribution'].fields.append(
  _PARAM.fields_by_name['external'])
_PARAM.fields_by_name['external'].containing_oneof = _PARAM.oneofs_by_name['distribution']
_PARAM.oneofs_by_name['distribution'].fields.append(
  _PARAM.fields_by_name['descrete'])
_PARAM.fields_by_name['descrete'].containing_oneof = _PARAM.oneofs_by_name['distribution']
_PARAM.oneofs_by_name['distribution'].fields.append(
  _PARAM.fields_by_name['uniform'])
_PARAM.fields_by_name['uniform'].containing_oneof = _PARAM.oneofs_by_name['distribution']
_GRIDSEARCH.fields_by_name['params'].message_type = _PARAM
_RANDOMSEARCH.fields_by_name['params'].message_type = _PARAM
_RUNSTATUS.fields_by_name['experiments'].message_type = _EXPERIMENTSUMMARYENTRY
_RUNSTATUS.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RUNSTATUS.fields_by_name['finish_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPERIMENTSUMMARYENTRY.fields_by_name['status'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
DESCRIPTOR.message_types_by_name['Run'] = _RUN
DESCRIPTOR.message_types_by_name['RunSpec'] = _RUNSPEC
DESCRIPTOR.message_types_by_name['ExperimentGenerator'] = _EXPERIMENTGENERATOR
DESCRIPTOR.message_types_by_name['Param'] = _PARAM
DESCRIPTOR.message_types_by_name['DiscreteSet'] = _DISCRETESET
DESCRIPTOR.message_types_by_name['UniformDistribution'] = _UNIFORMDISTRIBUTION
DESCRIPTOR.message_types_by_name['GridSearch'] = _GRIDSEARCH
DESCRIPTOR.message_types_by_name['RandomSearch'] = _RANDOMSEARCH
DESCRIPTOR.message_types_by_name['RunStatus'] = _RUNSTATUS
DESCRIPTOR.message_types_by_name['ExperimentSummaryEntry'] = _EXPERIMENTSUMMARYENTRY
DESCRIPTOR.enum_types_by_name['RunState'] = _RUNSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Run = _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
  'DESCRIPTOR' : _RUN,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Run)
  })
_sym_db.RegisterMessage(Run)

RunSpec = _reflection.GeneratedProtocolMessageType('RunSpec', (_message.Message,), {
  'DESCRIPTOR' : _RUNSPEC,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.RunSpec)
  })
_sym_db.RegisterMessage(RunSpec)

ExperimentGenerator = _reflection.GeneratedProtocolMessageType('ExperimentGenerator', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTGENERATOR,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ExperimentGenerator)
  })
_sym_db.RegisterMessage(ExperimentGenerator)

Param = _reflection.GeneratedProtocolMessageType('Param', (_message.Message,), {
  'DESCRIPTOR' : _PARAM,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Param)
  })
_sym_db.RegisterMessage(Param)

DiscreteSet = _reflection.GeneratedProtocolMessageType('DiscreteSet', (_message.Message,), {
  'DESCRIPTOR' : _DISCRETESET,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DiscreteSet)
  })
_sym_db.RegisterMessage(DiscreteSet)

UniformDistribution = _reflection.GeneratedProtocolMessageType('UniformDistribution', (_message.Message,), {
  'DESCRIPTOR' : _UNIFORMDISTRIBUTION,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UniformDistribution)
  })
_sym_db.RegisterMessage(UniformDistribution)

GridSearch = _reflection.GeneratedProtocolMessageType('GridSearch', (_message.Message,), {
  'DESCRIPTOR' : _GRIDSEARCH,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GridSearch)
  })
_sym_db.RegisterMessage(GridSearch)

RandomSearch = _reflection.GeneratedProtocolMessageType('RandomSearch', (_message.Message,), {
  'DESCRIPTOR' : _RANDOMSEARCH,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.RandomSearch)
  })
_sym_db.RegisterMessage(RandomSearch)

RunStatus = _reflection.GeneratedProtocolMessageType('RunStatus', (_message.Message,), {
  'DESCRIPTOR' : _RUNSTATUS,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.RunStatus)
  })
_sym_db.RegisterMessage(RunStatus)

ExperimentSummaryEntry = _reflection.GeneratedProtocolMessageType('ExperimentSummaryEntry', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTSUMMARYENTRY,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ExperimentSummaryEntry)
  })
_sym_db.RegisterMessage(ExperimentSummaryEntry)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
