# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/sshpublickey_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2
from grid.protos.grid.v1 import sshpublickey_pb2 as grid_dot_v1_dot_sshpublickey__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/sshpublickey_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"grid/v1/sshpublickey_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x13grid/v1/event.proto\x1a\x1agrid/v1/sshpublickey.proto\"V\n\x19\x43reateSSHPublicKeyRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"W\n\x1a\x43reateSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"(\n\x16GetSSHPublicKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"T\n\x17GetSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"\x9b\x01\n\x18ListSSHPublicKeysRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\"\xa8\x01\n\x19ListSSHPublicKeysResponse\x12\x39\n\x0csshpublickey\x18\x01 \x03(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"V\n\x19UpdateSSHPublicKeyRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"W\n\x1aUpdateSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"\\\n\x1fUpdateSSHPublicKeyStatusRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"]\n UpdateSSHPublicKeyStatusResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"V\n\x19\x44\x65leteSSHPublicKeyRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"W\n\x1a\x44\x65leteSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"u\n\x19WatchSSHPublicKeysRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\"\xaa\x01\n\x1aWatchSSHPublicKeysResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x12.grid.v1.EventTypeR\x04type\x12\x39\n\x0csshpublickey\x18\x03 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey2\xc0\x05\n\x13SSHPublicKeyService\x12_\n\x12\x43reateSSHPublicKey\x12\".grid.v1.CreateSSHPublicKeyRequest\x1a#.grid.v1.CreateSSHPublicKeyResponse\"\x00\x12V\n\x0fGetSSHPublicKey\x12\x1f.grid.v1.GetSSHPublicKeyRequest\x1a .grid.v1.GetSSHPublicKeyResponse\"\x00\x12\\\n\x11ListSSHPublicKeys\x12!.grid.v1.ListSSHPublicKeysRequest\x1a\".grid.v1.ListSSHPublicKeysResponse\"\x00\x12_\n\x12UpdateSSHPublicKey\x12\".grid.v1.UpdateSSHPublicKeyRequest\x1a#.grid.v1.UpdateSSHPublicKeyResponse\"\x00\x12o\n\x18UpdateSSHPublicKeyStatus\x12(.grid.v1.UpdateSSHPublicKeyStatusRequest\x1a).grid.v1.UpdateSSHPublicKeyStatusResponse\x12_\n\x12\x44\x65leteSSHPublicKey\x12\".grid.v1.DeleteSSHPublicKeyRequest\x1a#.grid.v1.DeleteSSHPublicKeyResponse\"\x00\x12_\n\x12WatchSSHPublicKeys\x12\".grid.v1.WatchSSHPublicKeysRequest\x1a#.grid.v1.WatchSSHPublicKeysResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_event__pb2.DESCRIPTOR,grid_dot_v1_dot_sshpublickey__pb2.DESCRIPTOR,])




_CREATESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='CreateSSHPublicKeyRequest',
  full_name='grid.v1.CreateSSHPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.CreateSSHPublicKeyRequest.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=236,
)


_CREATESSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='CreateSSHPublicKeyResponse',
  full_name='grid.v1.CreateSSHPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.CreateSSHPublicKeyResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=325,
)


_GETSSHPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='GetSSHPublicKeyRequest',
  full_name='grid.v1.GetSSHPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.GetSSHPublicKeyRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=367,
)


_GETSSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='GetSSHPublicKeyResponse',
  full_name='grid.v1.GetSSHPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.GetSSHPublicKeyResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=453,
)


_LISTSSHPUBLICKEYSREQUEST = _descriptor.Descriptor(
  name='ListSSHPublicKeysRequest',
  full_name='grid.v1.ListSSHPublicKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListSSHPublicKeysRequest.continue_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListSSHPublicKeysRequest.resource_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.ListSSHPublicKeysRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.ListSSHPublicKeysRequest.user_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=611,
)


_LISTSSHPUBLICKEYSRESPONSE = _descriptor.Descriptor(
  name='ListSSHPublicKeysResponse',
  full_name='grid.v1.ListSSHPublicKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.ListSSHPublicKeysResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListSSHPublicKeysResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListSSHPublicKeysResponse.resource_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=782,
)


_UPDATESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='UpdateSSHPublicKeyRequest',
  full_name='grid.v1.UpdateSSHPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.UpdateSSHPublicKeyRequest.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=870,
)


_UPDATESSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='UpdateSSHPublicKeyResponse',
  full_name='grid.v1.UpdateSSHPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.UpdateSSHPublicKeyResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=872,
  serialized_end=959,
)


_UPDATESSHPUBLICKEYSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateSSHPublicKeyStatusRequest',
  full_name='grid.v1.UpdateSSHPublicKeyStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.UpdateSSHPublicKeyStatusRequest.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=1053,
)


_UPDATESSHPUBLICKEYSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateSSHPublicKeyStatusResponse',
  full_name='grid.v1.UpdateSSHPublicKeyStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.UpdateSSHPublicKeyStatusResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1055,
  serialized_end=1148,
)


_DELETESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='DeleteSSHPublicKeyRequest',
  full_name='grid.v1.DeleteSSHPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.DeleteSSHPublicKeyRequest.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1150,
  serialized_end=1236,
)


_DELETESSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='DeleteSSHPublicKeyResponse',
  full_name='grid.v1.DeleteSSHPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.DeleteSSHPublicKeyResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1238,
  serialized_end=1325,
)


_WATCHSSHPUBLICKEYSREQUEST = _descriptor.Descriptor(
  name='WatchSSHPublicKeysRequest',
  full_name='grid.v1.WatchSSHPublicKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchSSHPublicKeysRequest.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.WatchSSHPublicKeysRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.WatchSSHPublicKeysRequest.user_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1327,
  serialized_end=1444,
)


_WATCHSSHPUBLICKEYSRESPONSE = _descriptor.Descriptor(
  name='WatchSSHPublicKeysResponse',
  full_name='grid.v1.WatchSSHPublicKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchSSHPublicKeysResponse.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.WatchSSHPublicKeysResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.WatchSSHPublicKeysResponse.sshpublickey', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1617,
)

_CREATESSHPUBLICKEYREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_CREATESSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_GETSSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_LISTSSHPUBLICKEYSRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYSTATUSREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYSTATUSRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_DELETESSHPUBLICKEYREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_DELETESSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_WATCHSSHPUBLICKEYSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_WATCHSSHPUBLICKEYSRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
DESCRIPTOR.message_types_by_name['CreateSSHPublicKeyRequest'] = _CREATESSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateSSHPublicKeyResponse'] = _CREATESSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['GetSSHPublicKeyRequest'] = _GETSSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['GetSSHPublicKeyResponse'] = _GETSSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['ListSSHPublicKeysRequest'] = _LISTSSHPUBLICKEYSREQUEST
DESCRIPTOR.message_types_by_name['ListSSHPublicKeysResponse'] = _LISTSSHPUBLICKEYSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyRequest'] = _UPDATESSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyResponse'] = _UPDATESSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyStatusRequest'] = _UPDATESSHPUBLICKEYSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyStatusResponse'] = _UPDATESSHPUBLICKEYSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSSHPublicKeyRequest'] = _DELETESSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['DeleteSSHPublicKeyResponse'] = _DELETESSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['WatchSSHPublicKeysRequest'] = _WATCHSSHPUBLICKEYSREQUEST
DESCRIPTOR.message_types_by_name['WatchSSHPublicKeysResponse'] = _WATCHSSHPUBLICKEYSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType('CreateSSHPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESSHPUBLICKEYREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateSSHPublicKeyRequest)
  })
_sym_db.RegisterMessage(CreateSSHPublicKeyRequest)

CreateSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType('CreateSSHPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESSHPUBLICKEYRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateSSHPublicKeyResponse)
  })
_sym_db.RegisterMessage(CreateSSHPublicKeyResponse)

GetSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType('GetSSHPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSSHPUBLICKEYREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetSSHPublicKeyRequest)
  })
_sym_db.RegisterMessage(GetSSHPublicKeyRequest)

GetSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType('GetSSHPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSSHPUBLICKEYRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetSSHPublicKeyResponse)
  })
_sym_db.RegisterMessage(GetSSHPublicKeyResponse)

ListSSHPublicKeysRequest = _reflection.GeneratedProtocolMessageType('ListSSHPublicKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSSHPUBLICKEYSREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListSSHPublicKeysRequest)
  })
_sym_db.RegisterMessage(ListSSHPublicKeysRequest)

ListSSHPublicKeysResponse = _reflection.GeneratedProtocolMessageType('ListSSHPublicKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSSHPUBLICKEYSRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListSSHPublicKeysResponse)
  })
_sym_db.RegisterMessage(ListSSHPublicKeysResponse)

UpdateSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType('UpdateSSHPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESSHPUBLICKEYREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyRequest)
  })
_sym_db.RegisterMessage(UpdateSSHPublicKeyRequest)

UpdateSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType('UpdateSSHPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESSHPUBLICKEYRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyResponse)
  })
_sym_db.RegisterMessage(UpdateSSHPublicKeyResponse)

UpdateSSHPublicKeyStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateSSHPublicKeyStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESSHPUBLICKEYSTATUSREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyStatusRequest)
  })
_sym_db.RegisterMessage(UpdateSSHPublicKeyStatusRequest)

UpdateSSHPublicKeyStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateSSHPublicKeyStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESSHPUBLICKEYSTATUSRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyStatusResponse)
  })
_sym_db.RegisterMessage(UpdateSSHPublicKeyStatusResponse)

DeleteSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType('DeleteSSHPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESSHPUBLICKEYREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteSSHPublicKeyRequest)
  })
_sym_db.RegisterMessage(DeleteSSHPublicKeyRequest)

DeleteSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType('DeleteSSHPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESSHPUBLICKEYRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteSSHPublicKeyResponse)
  })
_sym_db.RegisterMessage(DeleteSSHPublicKeyResponse)

WatchSSHPublicKeysRequest = _reflection.GeneratedProtocolMessageType('WatchSSHPublicKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHSSHPUBLICKEYSREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchSSHPublicKeysRequest)
  })
_sym_db.RegisterMessage(WatchSSHPublicKeysRequest)

WatchSSHPublicKeysResponse = _reflection.GeneratedProtocolMessageType('WatchSSHPublicKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHSSHPUBLICKEYSRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchSSHPublicKeysResponse)
  })
_sym_db.RegisterMessage(WatchSSHPublicKeysResponse)


DESCRIPTOR._options = None

_SSHPUBLICKEYSERVICE = _descriptor.ServiceDescriptor(
  name='SSHPublicKeyService',
  full_name='grid.v1.SSHPublicKeyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1620,
  serialized_end=2324,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSSHPublicKey',
    full_name='grid.v1.SSHPublicKeyService.CreateSSHPublicKey',
    index=0,
    containing_service=None,
    input_type=_CREATESSHPUBLICKEYREQUEST,
    output_type=_CREATESSHPUBLICKEYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSSHPublicKey',
    full_name='grid.v1.SSHPublicKeyService.GetSSHPublicKey',
    index=1,
    containing_service=None,
    input_type=_GETSSHPUBLICKEYREQUEST,
    output_type=_GETSSHPUBLICKEYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSSHPublicKeys',
    full_name='grid.v1.SSHPublicKeyService.ListSSHPublicKeys',
    index=2,
    containing_service=None,
    input_type=_LISTSSHPUBLICKEYSREQUEST,
    output_type=_LISTSSHPUBLICKEYSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSSHPublicKey',
    full_name='grid.v1.SSHPublicKeyService.UpdateSSHPublicKey',
    index=3,
    containing_service=None,
    input_type=_UPDATESSHPUBLICKEYREQUEST,
    output_type=_UPDATESSHPUBLICKEYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSSHPublicKeyStatus',
    full_name='grid.v1.SSHPublicKeyService.UpdateSSHPublicKeyStatus',
    index=4,
    containing_service=None,
    input_type=_UPDATESSHPUBLICKEYSTATUSREQUEST,
    output_type=_UPDATESSHPUBLICKEYSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSSHPublicKey',
    full_name='grid.v1.SSHPublicKeyService.DeleteSSHPublicKey',
    index=5,
    containing_service=None,
    input_type=_DELETESSHPUBLICKEYREQUEST,
    output_type=_DELETESSHPUBLICKEYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchSSHPublicKeys',
    full_name='grid.v1.SSHPublicKeyService.WatchSSHPublicKeys',
    index=6,
    containing_service=None,
    input_type=_WATCHSSHPUBLICKEYSREQUEST,
    output_type=_WATCHSSHPUBLICKEYSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SSHPUBLICKEYSERVICE)

DESCRIPTOR.services_by_name['SSHPublicKeyService'] = _SSHPUBLICKEYSERVICE

# @@protoc_insertion_point(module_scope)
