# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/run_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2
from grid.protos.grid.v1 import run_pb2 as grid_dot_v1_dot_run__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/run_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19grid/v1/run_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x13grid/v1/event.proto\x1a\x11grid/v1/run.proto\"2\n\x10\x43reateRunRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"3\n\x11\x43reateRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"\x1f\n\rGetRunRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"0\n\x0eGetRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"y\n\x0fListRunsRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\"\x84\x01\n\x10ListRunsResponse\x12\x1e\n\x03run\x18\x01 \x03(\x0b\x32\x0c.grid.v1.RunR\x03run\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"2\n\x10UpdateRunRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"3\n\x11UpdateRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"8\n\x16UpdateRunStatusRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"9\n\x17UpdateRunStatusResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"2\n\x10\x44\x65leteRunRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"3\n\x11\x44\x65leteRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"S\n\x10WatchRunsRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\"\x86\x01\n\x11WatchRunsResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x12.grid.v1.EventTypeR\x04type\x12\x1e\n\x03run\x18\x03 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run2\xfa\x03\n\nRunService\x12\x44\n\tCreateRun\x12\x19.grid.v1.CreateRunRequest\x1a\x1a.grid.v1.CreateRunResponse\"\x00\x12;\n\x06GetRun\x12\x16.grid.v1.GetRunRequest\x1a\x17.grid.v1.GetRunResponse\"\x00\x12\x41\n\x08ListRuns\x12\x18.grid.v1.ListRunsRequest\x1a\x19.grid.v1.ListRunsResponse\"\x00\x12\x44\n\tUpdateRun\x12\x19.grid.v1.UpdateRunRequest\x1a\x1a.grid.v1.UpdateRunResponse\"\x00\x12T\n\x0fUpdateRunStatus\x12\x1f.grid.v1.UpdateRunStatusRequest\x1a .grid.v1.UpdateRunStatusResponse\x12\x44\n\tDeleteRun\x12\x19.grid.v1.DeleteRunRequest\x1a\x1a.grid.v1.DeleteRunResponse\"\x00\x12\x44\n\tWatchRuns\x12\x19.grid.v1.WatchRunsRequest\x1a\x1a.grid.v1.WatchRunsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_event__pb2.DESCRIPTOR,grid_dot_v1_dot_run__pb2.DESCRIPTOR,])




_CREATERUNREQUEST = _descriptor.Descriptor(
  name='CreateRunRequest',
  full_name='grid.v1.CreateRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.CreateRunRequest.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=182,
)


_CREATERUNRESPONSE = _descriptor.Descriptor(
  name='CreateRunResponse',
  full_name='grid.v1.CreateRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.CreateRunResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=235,
)


_GETRUNREQUEST = _descriptor.Descriptor(
  name='GetRunRequest',
  full_name='grid.v1.GetRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.GetRunRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=268,
)


_GETRUNRESPONSE = _descriptor.Descriptor(
  name='GetRunResponse',
  full_name='grid.v1.GetRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.GetRunResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=318,
)


_LISTRUNSREQUEST = _descriptor.Descriptor(
  name='ListRunsRequest',
  full_name='grid.v1.ListRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListRunsRequest.continue_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListRunsRequest.resource_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.ListRunsRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=441,
)


_LISTRUNSRESPONSE = _descriptor.Descriptor(
  name='ListRunsResponse',
  full_name='grid.v1.ListRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.ListRunsResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListRunsResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListRunsResponse.resource_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=576,
)


_UPDATERUNREQUEST = _descriptor.Descriptor(
  name='UpdateRunRequest',
  full_name='grid.v1.UpdateRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.UpdateRunRequest.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=628,
)


_UPDATERUNRESPONSE = _descriptor.Descriptor(
  name='UpdateRunResponse',
  full_name='grid.v1.UpdateRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.UpdateRunResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=630,
  serialized_end=681,
)


_UPDATERUNSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateRunStatusRequest',
  full_name='grid.v1.UpdateRunStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.UpdateRunStatusRequest.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=739,
)


_UPDATERUNSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateRunStatusResponse',
  full_name='grid.v1.UpdateRunStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.UpdateRunStatusResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=798,
)


_DELETERUNREQUEST = _descriptor.Descriptor(
  name='DeleteRunRequest',
  full_name='grid.v1.DeleteRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.DeleteRunRequest.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=850,
)


_DELETERUNRESPONSE = _descriptor.Descriptor(
  name='DeleteRunResponse',
  full_name='grid.v1.DeleteRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.DeleteRunResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=903,
)


_WATCHRUNSREQUEST = _descriptor.Descriptor(
  name='WatchRunsRequest',
  full_name='grid.v1.WatchRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchRunsRequest.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.WatchRunsRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=988,
)


_WATCHRUNSRESPONSE = _descriptor.Descriptor(
  name='WatchRunsResponse',
  full_name='grid.v1.WatchRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchRunsResponse.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.WatchRunsResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.WatchRunsResponse.run', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=991,
  serialized_end=1125,
)

_CREATERUNREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_CREATERUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_GETRUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_LISTRUNSRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNSTATUSREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNSTATUSRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_DELETERUNREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_DELETERUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_WATCHRUNSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_WATCHRUNSRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
DESCRIPTOR.message_types_by_name['CreateRunRequest'] = _CREATERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateRunResponse'] = _CREATERUNRESPONSE
DESCRIPTOR.message_types_by_name['GetRunRequest'] = _GETRUNREQUEST
DESCRIPTOR.message_types_by_name['GetRunResponse'] = _GETRUNRESPONSE
DESCRIPTOR.message_types_by_name['ListRunsRequest'] = _LISTRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListRunsResponse'] = _LISTRUNSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateRunRequest'] = _UPDATERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateRunResponse'] = _UPDATERUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateRunStatusRequest'] = _UPDATERUNSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateRunStatusResponse'] = _UPDATERUNSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRunRequest'] = _DELETERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteRunResponse'] = _DELETERUNRESPONSE
DESCRIPTOR.message_types_by_name['WatchRunsRequest'] = _WATCHRUNSREQUEST
DESCRIPTOR.message_types_by_name['WatchRunsResponse'] = _WATCHRUNSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateRunRequest = _reflection.GeneratedProtocolMessageType('CreateRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateRunRequest)
  })
_sym_db.RegisterMessage(CreateRunRequest)

CreateRunResponse = _reflection.GeneratedProtocolMessageType('CreateRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateRunResponse)
  })
_sym_db.RegisterMessage(CreateRunResponse)

GetRunRequest = _reflection.GeneratedProtocolMessageType('GetRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetRunRequest)
  })
_sym_db.RegisterMessage(GetRunRequest)

GetRunResponse = _reflection.GeneratedProtocolMessageType('GetRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetRunResponse)
  })
_sym_db.RegisterMessage(GetRunResponse)

ListRunsRequest = _reflection.GeneratedProtocolMessageType('ListRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNSREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListRunsRequest)
  })
_sym_db.RegisterMessage(ListRunsRequest)

ListRunsResponse = _reflection.GeneratedProtocolMessageType('ListRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNSRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListRunsResponse)
  })
_sym_db.RegisterMessage(ListRunsResponse)

UpdateRunRequest = _reflection.GeneratedProtocolMessageType('UpdateRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunRequest)
  })
_sym_db.RegisterMessage(UpdateRunRequest)

UpdateRunResponse = _reflection.GeneratedProtocolMessageType('UpdateRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunResponse)
  })
_sym_db.RegisterMessage(UpdateRunResponse)

UpdateRunStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateRunStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNSTATUSREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunStatusRequest)
  })
_sym_db.RegisterMessage(UpdateRunStatusRequest)

UpdateRunStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateRunStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNSTATUSRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunStatusResponse)
  })
_sym_db.RegisterMessage(UpdateRunStatusResponse)

DeleteRunRequest = _reflection.GeneratedProtocolMessageType('DeleteRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteRunRequest)
  })
_sym_db.RegisterMessage(DeleteRunRequest)

DeleteRunResponse = _reflection.GeneratedProtocolMessageType('DeleteRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteRunResponse)
  })
_sym_db.RegisterMessage(DeleteRunResponse)

WatchRunsRequest = _reflection.GeneratedProtocolMessageType('WatchRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHRUNSREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchRunsRequest)
  })
_sym_db.RegisterMessage(WatchRunsRequest)

WatchRunsResponse = _reflection.GeneratedProtocolMessageType('WatchRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHRUNSRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchRunsResponse)
  })
_sym_db.RegisterMessage(WatchRunsResponse)


DESCRIPTOR._options = None

_RUNSERVICE = _descriptor.ServiceDescriptor(
  name='RunService',
  full_name='grid.v1.RunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1128,
  serialized_end=1634,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateRun',
    full_name='grid.v1.RunService.CreateRun',
    index=0,
    containing_service=None,
    input_type=_CREATERUNREQUEST,
    output_type=_CREATERUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRun',
    full_name='grid.v1.RunService.GetRun',
    index=1,
    containing_service=None,
    input_type=_GETRUNREQUEST,
    output_type=_GETRUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRuns',
    full_name='grid.v1.RunService.ListRuns',
    index=2,
    containing_service=None,
    input_type=_LISTRUNSREQUEST,
    output_type=_LISTRUNSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRun',
    full_name='grid.v1.RunService.UpdateRun',
    index=3,
    containing_service=None,
    input_type=_UPDATERUNREQUEST,
    output_type=_UPDATERUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRunStatus',
    full_name='grid.v1.RunService.UpdateRunStatus',
    index=4,
    containing_service=None,
    input_type=_UPDATERUNSTATUSREQUEST,
    output_type=_UPDATERUNSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRun',
    full_name='grid.v1.RunService.DeleteRun',
    index=5,
    containing_service=None,
    input_type=_DELETERUNREQUEST,
    output_type=_DELETERUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchRuns',
    full_name='grid.v1.RunService.WatchRuns',
    index=6,
    containing_service=None,
    input_type=_WATCHRUNSREQUEST,
    output_type=_WATCHRUNSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RUNSERVICE)

DESCRIPTOR.services_by_name['RunService'] = _RUNSERVICE

# @@protoc_insertion_point(module_scope)
